@@ -193,7 +193,7 @@ def tagger(text: str, task = 'full', lang = 'MSA') -> list:
     # Check if the ALMA dictionary has been loaded
     if settings.flag == True:
         settings.flag = False
-    settings.div_dic = load_ALMA_dic(r'data\my_data.pickle')
+    settings.div_dic = load_ALMA_dic()
    
     
     # Perform lemmatization on the input sentence
